@@ -1,30 +1,45 @@
-##' Analysis of Multivariate Events 
-##' 
+##' Analysis of Multivariate Events
+##'
 ##' Implementation of various statistical models for multivariate
 ##' event history data. Including multivariate cumulative incidence models,
-##' and bivariate random effects probit models (Liability models) 
+##' and bivariate random effects probit models (Liability models)
 ##'
 ##' @name mets-package
 ##' @docType package
 ##' @author Klaus K. Holst and Thomas Scheike
 ##' @useDynLib mets, .registration=TRUE
-##' @import stats splines timereg Rcpp mvtnorm
-##' @importFrom lava iid estimate bootstrap compare score information twostage %++% %ni% addvar<- blockdiag cancel Col
-##'                  confband constrain<- constraints covariance covariance<- coxWeibull.lvm devcoords distribution<-
-##'                  endogenous eventTime Expand getoutcome gof intercept<- Inverse kill<- latent latent<- lava.options lvm
-##'                  Model multigroup parameter<- pars regression regression<- revdiag sim trim
-##' @importFrom survival Surv is.Surv concordance
+##' @import stats splines Rcpp mvtnorm
+##' @importFrom lava iid estimate bootstrap compare score information twostage
+##'   %++% %ni% addvar<- blockdiag cancel Col confband constrain<- constraints
+##'   covariance covariance<- coxWeibull.lvm devcoords distribution<- endogenous
+##'   eventTime Expand getoutcome gof intercept<- Inverse kill<- latent latent<-
+##'   lava.options lvm Model multigroup parameter<- pars regression regression<-
+##'   revdiag trim IC expit logit
+##' @importFrom timereg two.stage predict.two.stage sindex.prodlim Cpred Event
+##' @importFrom survival Surv is.Surv concordance strata
 ##' @importFrom utils head tail getS3method glob2rx capture.output
-##' @importFrom graphics matplot lines plot polygon par points abline
-##'     title matlines
+##' @importFrom graphics matplot lines plot polygon par points abline title
+##'   matlines legend
 ##' @importFrom grDevices dev.list devAskNewPage dev.interactive
 ##' @keywords package
 ##' @examples
-##' 
+##'
 ##' ## To appear
-##' 
+##'
 NULL
 
+##' @export
+lava::IC
+
+##' @export
+lava::twostage
+
+##' @export
+lava::estimate
+
+##' @export
+lava::gof
+
 ##' np data set
 ##'
 ##' @name np
@@ -107,7 +122,7 @@ NULL
 ##'
 ##' @format
 ##' Self-reported BMI-values on 11,411 subjects
-##' 
+##'
 ##' tvparnr: twin id
 ##' bmi: BMI (m/kg^2)
 ##' age: Age
@@ -127,7 +142,7 @@ NULL
 NULL
 
 ##' For internal use
-##' 
+##'
 ##' @title For internal use
 ##' @name npc
 ##' @rdname internal
@@ -138,7 +153,7 @@ NULL
 ##'  alpha2kendall alpha2spear coefmat piecewise.twostage surv.boxarea
 ##'  faster.reshape piecewise.data
 ##'  simBinPlack simBinFam simBinFam2 simSurvFam corsim.prostate.random
-##'  simnordic.random simCox sim 
+##'  simnordic.random simCox sim
 ##'  grouptable jumptimes folds
 ##'  ace.family.design ascertained.pairs CCbinomial.twostage
 ##'  coarse.clust concordanceTwinACE concordanceTwostage
@@ -150,12 +165,11 @@ NULL
 ##'  simbinClaytonOakes.pairs simbinClaytonOakes.twin.ace
 ##'  simClaytonOakes.family.ace simClaytonOakes.twin.ace simFrailty.simple
 ##'  simCompete.simple simCompete.twin.ace twin.polygen.design
-##'  twostage.fullse
-##'  procform procform3 procformdata
+##'  procform procform3 procformdata drop.specials
 NULL
 
 
-##' Rate for leaving HPN program for patients of Copenhagen 
+##' Rate for leaving HPN program for patients of Copenhagen
 ##'
 ##' @name drcumhaz
 ##' @docType data
@@ -163,7 +177,7 @@ NULL
 ##' @source Estimated data
 NULL
 
-##' rate of CRBSI for HPN patients of Copenhagen 
+##' rate of CRBSI for HPN patients of Copenhagen
 ##'
 ##' @name base1cumhaz
 ##' @docType data
@@ -171,7 +185,7 @@ NULL
 ##' @source Estimated data
 NULL
 
-##' rate of Mechanical (hole/defect) complication for catheter of HPN patients of Copenhagen 
+##' rate of Mechanical (hole/defect) complication for catheter of HPN patients of Copenhagen
 ##'
 ##' @name base4cumhaz
 ##' @docType data
@@ -179,7 +193,7 @@ NULL
 ##' @source Estimated data
 NULL
 
-##' rate of Occlusion/Thrombosis complication for catheter of HPN patients of Copenhagen 
+##' rate of Occlusion/Thrombosis complication for catheter of HPN patients of Copenhagen
 ##'
 ##' @name base44cumhaz
 ##' @docType data
@@ -190,15 +204,15 @@ NULL
 
 ##' hapfreqs data set
 ##'
-##' @name hapfreqs 
+##' @name hapfreqs
 ##' @docType data
 ##' @keywords data
 ##' @source Simulated data
 NULL
 
-##' haploX  covariates and response for haplo survival discrete survival 
+##' haploX  covariates and response for haplo survival discrete survival
 ##'
-##' @name haploX 
+##' @name haploX
 ##' @docType data
 ##' @keywords data
 ##' @source Simulated data
@@ -206,11 +220,16 @@ NULL
 
 ##' ghaplos  haplo-types for subjects of haploX data
 ##'
-##' @name ghaplos 
+##' @name ghaplos
 ##' @docType data
 ##' @keywords data
 ##' @source Simulated data
 NULL
 
-
-
+##' ttpd discrete survival data on interval form
+##'
+##' @name ttpd
+##' @docType data
+##' @keywords data
+##' @source Simulated data
+NULL
