@@ -1,3 +1,4 @@
+
 #include <RcppArmadillo.h>
 #include <Rcpp.h>
 #include <algorithm>
@@ -701,7 +702,8 @@ double val,val2,val3,val4;
 //double laplace(),ilaplace(),Dilaplace(),Dlaplace(),D2laplace(); 
 double t0;
 
-if (x<0) x=0.0001; if (y<0) y=0.0001; 
+if (x<0) x=0.0001;
+if (y<0) y=0.0001; 
 
 val=ilaplace(t,exp(-x))+ilaplace(t,exp(-y)); val2=laplace(t,val); 
 ckij(0)=1-exp(-x)-exp(-y)+val2; 
@@ -969,14 +971,14 @@ RcppExport SEXP cor(SEXP itimes,SEXP iy,SEXP icause, SEXP iCA1, SEXP iKMc,
 	  time=times(s); 
           rowvec bhatt = est.row(s); 
           vec pbhat = z * trans(bhatt); 
-	  if ((semi==1) & (cifmodel==1)) pbhat = pbhat + Zgamma*time;
-	  if ((semi==1) & (cifmodel==2))  pbhat=pbhat%exp(Zgamma); 
+	  if ((semi==1) && (cifmodel==1)) pbhat = pbhat + Zgamma*time;
+	  if ((semi==1) && (cifmodel==2))  pbhat=pbhat%exp(Zgamma);
 
 	  if ((CA1!=CA2)) {
 		  bhatt2 = est2.row(s); 
 		   pbhat2 = z2 * trans(bhatt2); 
-	     if ((semi2==1) & (cifmodel==1)) pbhat2 = pbhat2 + Z2gamma2*time;
-	     if ((semi2==1) & (cifmodel==2)) pbhat2=pbhat2%exp(Z2gamma2); 
+	     if ((semi2==1) && (cifmodel==1)) pbhat2 = pbhat2 + Z2gamma2*time;
+	     if ((semi2==1) && (cifmodel==2)) pbhat2=pbhat2%exp(Z2gamma2);
 	  }
 
     for (j=0;j<antclust;j++) if (clustsize(j)>=2) { 
